Receiver operator characteristic (ROC) curves for logistic regression. Repeated k-fold cross-validation was used to predict class given the log-ratio of the top and bottom {{snakemake.wildcards.pctile}}% of features.
